==> fswiki-3.5.6.tbz: share/fswiki/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# <p>ХݡȤƤ뤿Υեɽޤ</p>
# <p>
#   Ȥƥץ̾ӥХΥƥꤷޤ
# </p>
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# <p>
#   ΥեफХݡȤƤ
# </p>
# <pre>
# BugTrack-ץ̾/ֹ
# </pre>
# <p>
#   Ȥ̾Υڡޤ
#   ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
#   ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
#   񤭴Ƥ
# </p>
# 
################################################################################
package plugin::bugtrack::BugTrack;
use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# ѥ饰
#===============================================================================
sub paragraph {
	my $self     = shift;
	my $wiki     = shift;
	my $project  = shift;
	my @category = @_;
	my $cgi      = $wiki->get_CGI();
	
	if($project eq ""){
		return &Util::paragraph_error("ץ̾ꤵƤޤ");
	}
	if($#category == -1){
		return &Util::paragraph_error("ƥ꤬ꤵƤޤ");
	}
	
	my $template = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bugtrack.tmpl",
	                                   die_on_bad_params => 0);
	
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$template->param(PRIORITY => &make_array_ref(@priority));
	$template->param(STATUS   => &make_array_ref(@status));
	$template->param(CATEGORY => &make_array_ref(@category));
	
	# ̾
	my $name = '';
	if($wiki->use_cache($cgi->param('page'))){
		$name = $cgi->cookie(-name=>'post_name');
		if($name eq ''){
			my $login = $wiki->get_login_info();
			if(defined($login)){
				$name = $login->{id};
			}
		}
	}
	$template->param(NAME=>$name);
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\">\n".
	          $template->output().
	          "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	          "<input type=\"hidden\" name=\"project\" value=\"".&Util::escapeHTML($project)."\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ܤե󥹤
#===============================================================================
sub make_array_ref {
	my @array    = @_;
	my $arrayref = [];
	foreach(@array){
		push(@$arrayref,{NAME=>$_,VALUE=>$_});
	}
	return $arrayref;
}


1;

==> fswiki-3.6.2_1.tbz: share/fswiki/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# <p>ХݡȤƤ뤿Υեɽޤ</p>
# <p>
#   Ȥƥץ̾ӥХΥƥꤷޤ
# </p>
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# <p>
#   ΥեफХݡȤƤ
# </p>
# <pre>
# BugTrack-ץ̾/ֹ
# </pre>
# <p>
#   Ȥ̾Υڡޤ
#   ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
#   ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
#   񤭴Ƥ
# </p>
# 
################################################################################
package plugin::bugtrack::BugTrack;
use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# ѥ饰
#===============================================================================
sub paragraph {
	my $self     = shift;
	my $wiki     = shift;
	my $project  = shift;
	my @category = @_;
	my $cgi      = $wiki->get_CGI();
	
	if($project eq ""){
		return &Util::paragraph_error("ץ̾ꤵƤޤ");
	}
	if($#category == -1){
		return &Util::paragraph_error("ƥ꤬ꤵƤޤ");
	}
	
	my $template = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bugtrack.tmpl",
	                                   die_on_bad_params => 0);
	
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$template->param(PRIORITY => &make_array_ref(@priority));
	$template->param(STATUS   => &make_array_ref(@status));
	$template->param(CATEGORY => &make_array_ref(@category));
	
	# ̾
	my $name = $cgi->cookie(-name=>'post_name');
	if($name eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$name = $login->{id};
		}
	}
	$template->param(NAME=>$name);
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\">\n".
	          $template->output().
	          "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	          "<input type=\"hidden\" name=\"project\" value=\"".&Util::escapeHTML($project)."\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ܤե󥹤
#===============================================================================
sub make_array_ref {
	my @array    = @_;
	my $arrayref = [];
	foreach(@array){
		push(@$arrayref,{NAME=>$_,VALUE=>$_});
	}
	return $arrayref;
}


1;
